@@ -1,9 +1,15 @@
+#' matches 
+#' 
+#' @param query Required. A SMARTSQuery
+#' @param target Required. The molecule to query. Should be a `jobjRef` representing an `IAtomContainer`
+#' @param return.matches Optional. Default \code{FALSE}
+#' @export
 matches <- function(query, target, return.matches=FALSE) {
   if (!is.list(target)) target <- list(target)
   if (!all(unlist(lapply(target, class)) == 'jobjRef'))
     stop("targets must be a list of IAtomContainer objects or a single IAtomContainer object")
 
-  dcob <- .get.chem.object.builder()
+  dcob <- get.chem.object.builder()
 
   ## make an SQT
   sqt <- new(J("org/openscience/cdk/smiles/smarts/SMARTSQueryTool"), query, dcob)
